@@ -62,7 +62,7 @@ class VimanPoster(PocolibsDataStreamOutput):
     _type_url = "http://trac.laas.fr/git/viman-genom/tree/vimanStruct.h#n139"
 
     def initialize(self):
-        super(self.__class__, self).initialize(VimanObjectPublicArray)
+        PocolibsDataStreamOutput.initialize(self, VimanObjectPublicArray)
 
         # Initialise the object
         self.obj = VimanObjectPublicArray()
@@ -88,7 +88,7 @@ class VimanPoster(PocolibsDataStreamOutput):
         for object in self.scene_object_list:
             logger.info("Adding " + object + " to the objects tracked by VIMAN")
             self.obj.objects[i].name = bytes(str(object), 'utf-8')
-            i = i + 1
+            i += 1
 
     def _read_object_list(self):
         """ Open the file specified in the object_config_file variable
@@ -102,7 +102,7 @@ class VimanPoster(PocolibsDataStreamOutput):
             fp = open(object_config_file, "r")
             for line in fp:
                 match = re.search('object (\w+)', line)
-                if match != None:
+                if match is not None:
                     scene_object_list.append(match.group(1))
                     logger.debug("\t- %s" % match.group(1))
             fp.close()
@@ -139,7 +139,7 @@ class VimanPoster(PocolibsDataStreamOutput):
                     self.obj.objects[i].found_Stereo = 0
             except KeyError as detail:
                 logger.debug("WARNING: Object %s not found in the scene" % detail)
-            i = i + 1
+            i += 1
         self.write(self.obj)
 
 
