@@ -1,9 +1,9 @@
 import logging; logger = logging.getLogger("morse." + __name__)
-import roslib; roslib.load_manifest('sensor_msgs');
+import roslib; roslib.load_manifest('sensor_msgs')
 from sensor_msgs.msg import JointState
-from morse.middleware.ros import ROSReader
+from morse.middleware.ros import ROSSubscriber
 
-class JointStateReader(ROSReader):
+class JointStateReader(ROSSubscriber):
     """ Subscribe to a JointState topic and set kuka_{1-7} to the position[0-6]. """
     ros_class = JointState
 
