@@ -1,6 +1,5 @@
 import logging; logger = logging.getLogger("morse." + __name__)
 import morse.core.sensor
-import time
 from morse.helpers.components import add_data, add_property
 
 class Battery(morse.core.sensor.Sensor):
@@ -15,13 +14,14 @@ class Battery(morse.core.sensor.Sensor):
     This rate is independent of the actions performed by the robot, and
     only dependant on the time elapsed since the beginning of the simulation.
 
-    A planned feature is to allow for designated **Charging Zones** where
-    the battery will gradually recharge. However, this is not implemented yet.
+    If the battery enters in a **Charging zone**, the battery will
+    gradually recharge.
     """
 
     _name = "Battery Sensor"
 
-    add_property('_discharging_rate', 0.05, 'DischargingRate', "float", "Battery discharging rate, in percent per seconds")
+    add_property('_discharging_rate', 0.05, 'DischargingRate', "float",
+                  "Battery discharging rate, in percent per seconds")
 
     add_data('charge', 100.0, "float", "Initial battery level, in percent")
 
@@ -31,23 +31,22 @@ class Battery(morse.core.sensor.Sensor):
             The second parameter should be the name of the object's parent. """
         logger.info("%s initialization" % obj.name)
         # Call the constructor of the parent class
-        super(self.__class__,self).__init__(obj, parent)
+        morse.core.sensor.Sensor.__init__(self, obj, parent)
 
-        self._time = time.time()
+        self._time = self.robot_parent.gettime()
 
         logger.info('Component initialized, runs at %.2f Hz', self.frequency)
 
     def default_action(self):
         """ Main function of this component. """
-        newtime = time.time()
         charge = self.local_data['charge']
-        dt = newtime - self._time
+        dt = (self.robot_parent.gettime() - self._time) / 1000.0
 
-        if self.isInChargingZone() and charge < 100:
+        if self.in_zones(type = 'Charging'):
             charge = charge + dt * self._discharging_rate
             if charge > 100.0:
                 charge = 100.0
-        elif charge > 0:
+        else:
             charge = charge - dt * self._discharging_rate
             if charge < 0.0:
                 charge = 0.0
@@ -56,15 +55,4 @@ class Battery(morse.core.sensor.Sensor):
         #  via a middleware.
         self.local_data['charge'] = float(charge)
         # update the current time
-        self._time = newtime
-
-
-
-    def isInChargingZone(self):
-        # Test if the robot (parent) is in a charging zone
-        pose = self.position_3d
-        # look for a charging zon in the scene
-        # TODO for 'charging_zone' in scene:
-        # if the robot is near the zone, return true
-        return False
-
+        self._time = self.robot_parent.gettime()
