@@ -12,9 +12,14 @@ class Camera(morse.core.sensor.Sensor):
     A generic camera class, which is expected to be used as a base class
     for real camera. Concrete instantiation are currently:
 
-        - :doc:`video_camera <../sensors/video_camera>`
-        - :doc:`depth_camera <../sensors/depth_camera>`
-        - :doc:`semantic_camera <../sensors/semantic_camera>`
+    - :doc:`video_camera <../sensors/video_camera>`
+    - :doc:`depth_camera <../sensors/depth_camera>`
+    - :doc:`semantic_camera <../sensors/semantic_camera>`
+
+    .. note::
+        The cameras make use of Blender's **bge.texture** module, which
+        requires a graphic card capable of GLSL shading. Also, the 3D view
+        window in Blender must be set to draw **Textured** objects.
 
     .. note::
         The streaming of data from this sensor can be toggled off and on by
@@ -24,6 +29,12 @@ class Camera(morse.core.sensor.Sensor):
         Toggling off the cameras can help make the simulation run faster,
         specially when there are several cameras. However, the lack of
         data on the stream may cause problems to some middlewares.
+
+    .. warning::
+        Contrary to most of objects in Morse, the X axis of the camera
+        is not "in front" of the camera. Here, Morse follows the
+        "standard convention for camera", i.e.  X and Y are in the image
+        plane, and Z is in the depth axis of the camera.
     """
 
     _name = "Generic Camera"
@@ -57,7 +68,19 @@ class Camera(morse.core.sensor.Sensor):
         self._camera_running = False
 
         self.scene_name = 'S.%dx%d' % (self.image_width, self.image_height)
-        blenderapi.add_scene(self.scene_name, overlay=0)
+
+        persistantstorage = morse.core.blenderapi.persistantstorage()
+        parent_name = self.robot_parent.name()
+        is_parent_external = False
+
+        for robot in persistantstorage.externalRobotDict.keys():
+            if robot.name == parent_name:
+                is_parent_external = True
+                break
+
+        if not is_parent_external:
+            logger.info("Adding scene %s" % self.scene_name)
+            blenderapi.add_scene(self.scene_name, overlay=0)
         logger.info('Component initialized, runs at %.2f Hz', self.frequency)
 
     def default_action(self):
@@ -85,16 +108,12 @@ class Camera(morse.core.sensor.Sensor):
             # Call the bge.texture method to refresh the image
             blenderapi.cameras()[self.name()].refresh(True)
 
-    def _update_pose(self, obj):
-        copy_pose(self._morse_scene.objects[obj.name], obj)
-
     def _update_scene(self):
-        for obj in self._scene.objects:
-            if obj.name != '__default__cam__':
-                try:
-                    self._update_pose(obj)
-                except Exception as e:
-                    logger.warning(str(e))
+        for _to, _from in self._scene_syncable_objects:
+            try:
+                copy_pose(_from, _to)
+            except Exception as e:
+                logger.warning(str(e))
 
     def _setup_video_texture(self):
         """ Prepare this camera to use the bge.texture module.
@@ -133,6 +152,57 @@ class Camera(morse.core.sensor.Sensor):
         self._scene = scene_map[self.scene_name]
         self._morse_scene = scene_map['S.MORSE_LOGIC']
 
+        """
+        Compute the relation between objects in the current scene and
+        objects in the main logic scene.
+
+        The logic is a bit complex, as in the case of group, we can have
+        objects with the same name (but different ids). So, in this
+        case, we follow the hierarchy on both scene to find
+        correspondance (assuming no recursive group)
+
+        known_ids is used to track objects alreay referenced and not
+        include it twice (and possibly missing the fact that the same
+        name can reference multiples different objects)
+
+        I'm definitively not sure it is correct at all, it is a really
+        really dark corner of Blender :). But it seems to do the job!
+        """
+        self._scene_syncable_objects = []
+        known_ids = set()
+        for obj in self._scene.objects:
+            if obj.name != '__default__cam__' and id(obj) not in known_ids:
+                if blenderapi.version() < (2, 63, 0):
+                    members = None
+                elif blenderapi.version() < (2, 64, 0):
+                    members = obj.group
+                elif blenderapi.version() < (2, 65, 0):
+                    members = obj.group_parent
+                else:
+                    members = obj.groupMembers
+                if not members:
+                    self._scene_syncable_objects.append(
+                            (obj, self._morse_scene.objects[obj.name]))
+                    known_ids.add(id(obj))
+                else:
+                    if blenderapi.version() < (2, 64, 0):
+                        main_members = self._morse_scene.objects[obj.name].group
+                    elif blenderapi.version() < (2, 65, 0):
+                        main_members = self._morse_scene.objects[obj.name].group_parent
+                    else:
+                        main_members = self._morse_scene.objects[obj.name].groupMembers
+                    for i in range(0, len(main_members)):
+                        self._scene_syncable_objects.append(
+                                (members[i], main_members[i]))
+                        known_ids.add(id(members[i]))
+                        childs = members[i].childrenRecursive
+                        main_childs = main_members[i].childrenRecursive
+                        for child in childs:
+                            self._scene_syncable_objects.append(
+                                    (child, main_childs[child.name]))
+                            known_ids.add(id(child))
+
+
         # Link the objects using bge.texture
         if not blenderapi.hascameras():
             blenderapi.initcameras()
