@@ -40,7 +40,7 @@ class CompoundSensor(morse.core.sensor.Sensor):
             logger.error("The compound sensor <%s> has no sensors list associated!" % obj.name)
             return
 
-        self.local_data = {}
+        self._initialized = False
 
     def _get_sensors_references(self):
         # Get the reference to all components
@@ -63,5 +63,6 @@ class CompoundSensor(morse.core.sensor.Sensor):
         Default action does nothing at all, since self.local_data stores
         references to sub sensors' local_data, so it get updated for free.
         """
-        if not self.local_data:
+        if not self._initialized:
             self._get_sensors_references()
+            self._initialized = True
